@@ -1,9 +1,9 @@
 # Verilog - Verilog Perl Interface
-# $Id: File.pm 25882 2006-10-02 13:22:45Z wsnyder $
+# $Id: File.pm 29806 2007-01-10 13:04:28Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
-# Copyright 2000-2006 by Wilson Snyder.  This program is free software;
+# Copyright 2000-2007 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 # 
@@ -22,7 +22,7 @@ use Verilog::Netlist;
 use Verilog::Netlist::Subclass;
 @ISA = qw(Verilog::Netlist::File::Struct
 	Verilog::Netlist::Subclass);
-$VERSION = '2.361';
+$VERSION = '2.370';
 use strict;
 
 structs('new',
@@ -164,10 +164,11 @@ sub signal_decl {
 	$net or $net = $modref->new_net
 	    (name=>$netname,
 	     filename=>$self->filename, lineno=>$self->lineno,
-	     simple_type=>1, type=>'wire', array=>$array,
+	     simple_type=>1, type=>$inout, array=>$array,
 	     comment=>undef, msb=>$msb, lsb=>$lsb,
 	     signed=>$signed,
 	     );
+	$net->type($inout);  # If it's already declared as in/out etc, mark the type
 	$self->{_cmtref} = $net;
     }
     elsif ($inout =~ /(inout|in|out)(put|)$/) {
@@ -393,7 +394,7 @@ Verilog-Perl is part of the L<http://www.veripool.com/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.com/verilog-perl.html>.
 
-Copyright 2000-2006 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2007 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License or the Perl Artistic License.
 
